Learn R Programming

molnet (version 0.1.0)

inter_layer_edgelist_by_id: Interlayer conntections by identifiers

Description

(INTERNAL) Returns an edge list defining the connections between two layers of the network.

Usage

inter_layer_edgelist_by_id(annotation_1, annotation_2, connection, weight = 1)

Arguments

annotation_1, annotation_2

Data frames: Annotation tables specifying the identifiers of the nodes of a network

connection

String of identifier to connect on

weight

Integer or vector specifying the weight of the inter-layer connections.

Value

data.frame with columns from, to and weight