Learn R Programming

molnet (version 0.1.0)

inter_layer_edgelist_by_table: Interaction table to iGraph graph object

Description

(INTERNAL) Returns an edge list defining the connections between two layers of the network based on an interaction table supplied by the user.

Usage

inter_layer_edgelist_by_table(
  annotation_1,
  annotation_2,
  interaction_table,
  weight_column
)

Arguments

annotation_1, annotation_2

Data frames: Annotation tables specifying the identifiers of the nodes of a network

interaction_table

Table specifying the interaction / connections between the two layers

weight_column

Name of the column in 'interaction_table' giving the weight of the inter-layer edges.

Value

data.frame with columns from, to and weight