(INTERNAL) Returns an edge list defining the connections between two layers of the network.
inter_layer_edgelist_by_id(annotation_1, annotation_2, connection, weight = 1)Data frames: Annotation tables specifying the identifiers of the nodes of a network
String of identifier to connect on
Integer or vector specifying the weight of the inter-layer connections.
data.frame with columns from, to and weight