(INTERNAL) Returns an edge list defining the connections between two layers of the network based on an interaction table supplied by the user.
inter_layer_edgelist_by_table(
annotation_1,
annotation_2,
interaction_table,
weight_column
)Data frames: Annotation tables specifying the identifiers of the nodes of a network
Table specifying the interaction / connections between the two layers
Name of the column in 'interaction_table' giving the weight of the inter-layer edges.
data.frame with columns from, to and weight